<h1 align="center">Manim-CS</h1 >
<p align="center">
    <br />
    <a href="https://pypi.org/project/manimcs/"><img src="https://img.shields.io/pypi/v/manimcs.svg?style=flat&logo=pypi" alt="PyPI Latest Release"></a>
    <a href="https://hub.docker.com/r/manimcommunity/manim"><img src="https://img.shields.io/docker/v/manimcommunity/manim?color=%23099cec&label=docker%20image&logo=docker" alt="Docker image"> </a>
    <a href="https://mybinder.org/v2/gh/ManimCommunity/jupyter_examples/HEAD?filepath=basic_example_scenes.ipynb"><img src="https://mybinder.org/badge_logo.svg"></a>
    <a href="http://choosealicense.com/licenses/mit/"><img src="https://img.shields.io/badge/license-MIT-red.svg?style=flat" alt="MIT License"></a>
    <!-- <a href="https://docs.manim.community/"><img src="https://readthedocs.org/projects/manimce/badge/?version=latest" alt="Documentation Status"></a>
    <a href="https://pepy.tech/project/manim"><img src="https://pepy.tech/badge/manim/month?" alt="Downloads"> </a> -->
    <img src="https://github.com/ManimCommunity/manim/workflows/CI/badge.svg" alt="CI">
    <br />
    <br />
    <i>An animation library for explanatory Computer Science videos</i>
</p>
<hr />

This is an extension of the 3B1B library for animating with python. Manim CS provides additional MObjects, and Animation sequinces to provide support for rendering sorting algorithms, tree structure, and memory simulations. 

## Table of Contents:

-  [Installation](#installation)
-  [Prerequisites](#Prerequisites)




## Prerequisites: 

- <div><h3 >Manim Community</h3> Follow the <a href="https://docs.manim.community/en/stable/installation.html"> Official Documentation </a> to install the Manim Animation Library for Python 
- <div><h3 >LaTeX</h3> Follow the <a href="https://www.latex-project.org/get/"> Official Documentation </a> to install LaTeX on your system. 
## Installation

- <h4>Option 1: Package Installer for Python</h4> Install the official <a href="https://pypi.org/project/manimcs/"> PyPy Release </a> by running: 
```bash
$ pip install manimcs